% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/general-functions.R
\name{compareICL}
\alias{compareICL}
\title{Compare corrected ICL values after data transformation}
\usage{
compareICL(x)
}
\arguments{
\item{x}{A list made up of \code{coseqResults} objects. At the current time, this function
only supports the comparison of \code{coseqResults} objects using \code{model="Normal"} and
\code{transformation = c("arcsin", "logit", "logMedianRef")}}
}
\value{
A plot of corrected ICL values for the models included in \code{x} (the list
of \code{coseqResults} objects)
}
\description{
Compare the corrected ICL values after applying the arcsin, logit, and logMedianRef
transformations in a coseq analysis
}
\examples{
## Simulate toy data, n = 300 observations
set.seed(12345)
countmat <- matrix(runif(300*4, min=0, max=500), nrow=300, ncol=4)
countmat <- countmat[which(rowSums(countmat) > 0),]
conds <- rep(c("A","B","C","D"), each=2)

## Run the Normal mixture model for K = 2,3,4
run_arcsin <- coseq(object=countmat, K=2:4, iter=5, transformation="arcsin",
                    model="Normal", seed=12345)
run_arcsin

## Plot and summarize results
plot(run_arcsin)
summary(run_arcsin)

## Compare ARI values for all models (no plot generated here)
ARI <- compareARI(run_arcsin, plot=FALSE)

## Compare ICL values for models with arcsin and logit transformations
run_logit <- coseq(object=countmat, K=2:4, iter=5, transformation="logit",
                   model="Normal")
compareICL(list(run_arcsin, run_logit))

## Use accessor functions to explore results
clusters(run_arcsin)
likelihood(run_arcsin)
nbCluster(run_arcsin)
ICL(run_arcsin)

## Examine transformed counts and profiles used for graphing
tcounts(run_arcsin)
profiles(run_arcsin)

## Run the K-means algorithm for logclr profiles for K = 2,..., 20
run_kmeans <- coseq(object=countmat, K=2:20, transformation="logclr",
                    model="kmeans")
run_kmeans
}
\author{
Andrea Rau, Cathy Maugis-Rabusseau
}
